@@ -11,6 +11,10 @@ class PrecursorEnum(Enum):
     PRJPG = 'prjpg'
     PNGZO = 'pngzo'
 
+    @staticmethod
+    def list():
+        return list(map(lambda c: c.value, PrecursorEnum))
+
 
 class PrecursorToExtensionEnum(Enum):
     WEBP0 = '.webp'
