@@ -48,6 +48,36 @@ class RejectionNotice(NamedTuple):
     inner_error: Optional[RequestIssueException] = None
 
 
+class RejectionNoticeToHumanEnum(Enum):
+    ACCESS_DENIED = (
+        "Access denied failure! Invalid authentication token or domain name, "
+        "please make sure you set the right api token and domain for "
+        "the request."
+    )
+    IMAGE_IS_TOO_BIG = (
+        "Optimized image too big failure! Not possible to create an optimized "
+        "image that has a smaller size and also preserves quality of the "
+        "original file. Use the max_overhead parameter if you want to get an "
+        "optimized image which is bigger than the original image. "
+        "Read more here: "
+        "https://demo.pixellena.com/adjustments about this parameter."
+    )
+    UNCLEAR = (
+        "Unclear failure! We could not get the optimized image either because "
+        "the download "
+        "link was not generated or because we could not download the image "
+        "from the bucket."
+    )
+    HTTP_REQUEST_ERROR = (
+        "Http requester error! See the rejection_notice and the inner_error "
+        "for more details."
+    )
+    TIMEOUT = (
+        "Timeout failure! We got a timeout error from the toilmore API, please "
+        "try again later."
+    )
+
+
 class OptimizationResponseStatus(Enum):
     SUCCESS = 'SUCCESS'
     FAILURE = 'FAILURE'
@@ -200,7 +230,7 @@ class Toilmore(object):
         :param image_arg: The contents of the image to optimize.
         :param precursor: The precursor (see above).
         :param adjustments: see Adjustments: https://pixellena.com/lux-api/
-     *                    in our API docs.
+                            in our API docs.
         :param envelope_options: Object with other misc options that the API
             accept, optional.
         :return:
@@ -216,6 +246,19 @@ class Toilmore(object):
                 status=OptimizationResponseStatus.FAILURE,
                 rejection_notice=rn
             )
+        allowed_precursors = constants.PrecursorEnum.list()
+        if precursor.value not in allowed_precursors:
+            rn = RejectionNotice(
+                rejection_notice=RejectionNoticeEnum.HTTP_REQUEST_ERROR,
+                inner_error=RequestIssueException(
+                    f'WrongPrecursor. Allowed values are: {allowed_precursors}'
+                )
+            )
+            return OptimizationResponse(
+                status=OptimizationResponseStatus.FAILURE,
+                rejection_notice=rn
+            )
+
         self.emit_debug_message('Starting to optimize the image...')
         return await self.optimize_with_precursor(
             image_arg,
